/*
 * DS Lightbox system plugin for Joomla! 2.5 & 3.x
 * Version   2.1
 * URL: http://dzyanis.com/myprojects/dslightbox
 * The lightbox engine taken from next source (MIT License):
 * https://github.com/duncanmcdougall/Responsive-Lightbox
 * Some modifications have been done by DS:
 * [DS:A] - code has been added below
 * [DS:C] - code has been changed in the marked row
 */
 
// Initiate Lightbox
jQuery(function() {
  jQuery('.ds-lb').ds_lightbox(); // 'gallery' to 'ds-lb' <- [DS]
});

(function (jQuery) {

    'use strict';

    jQuery.fn.ds_lightbox = function (options) {
		
      var opts = {
			margin: 86,
			nav: true,
			navLoop: false, // <- [DS:C]
			blur: false,
			fadeIn_speed: 'fast', // <- [DS:A]
			fadeOut_speed: 'fast', // <- [DS:A]
			minSize: 0,
			ds_prev: 'Previous', // <- [DS:A]
			ds_next: 'Next', // <- [DS:A]
			ds_close: 'Click to close', // <- [DS:A]
			ds_fullscreen: 'Full screen', // <- [DS:A]
			ds_exitfullscreen: 'Exit full screen' // <- [DS:A]
    };
		
		// Switch ON the allery navigation [DS:A]
		if (typeof ds_opts_nav == "undefined") {
			opts.nav = false;
		}
		// End of Switch ON the allery navigation [DS:A]
		
        var plugin = {

            items: [],
            ds_lightbox: null,
            image: null,
            current: null,
            locked: false,
            caption: null,
			
            init: function (items) {
                plugin.items = items;
                var id = 'ds-lightbox-' + Math.floor((Math.random() * 100000) + 1);
                if (!plugin.ds_lightbox) {
                    plugin.ds_lightbox = jQuery('body').find('.bodyGlobalLightbox');

                    if (plugin.ds_lightbox.length === 0) {
						
						// Overlay items [DS:C+A]
						var ds_overlay_items = '<div id="'+id+'" class="ds-lightbox bodyGlobalLightbox" style="display:none;">'+
                        '<span title="'+opts.ds_close+'" class="ds-lightbox_close ds-lightbox_button flaticon-cross92"></span>' + 
						'<span title="'+opts.ds_fullscreen+'" class="ds-lightbox_fullscreen ds-lightbox_button flaticon-full5" ></span>' + 
						'<span title="'+opts.ds_exitfullscreen+'" class="ds-lightbox_exitfullscreen ds-lightbox_button flaticon-fullscreen5" ></span>' + 
						'<span title="'+opts.ds_prev+'" class="ds-lightbox_nav ds-lightbox_nav--prev ds-lightbox_button flaticon-direction129"></span>' +
                        '<span title="'+opts.ds_next+'" class="ds-lightbox_nav ds-lightbox_nav--next ds-lightbox_button flaticon-fastforward4"></span>' +
                        '<div href="#" class="ds-lightbox_caption"><p></p></div>' +
                        '</div>';

                        jQuery('body').append(ds_overlay_items);
						// End of Overlay items [DS:C+A]

                        plugin.ds_lightbox = jQuery("#"+id);
                    }

                    plugin.caption = jQuery('.ds-lightbox_caption', plugin.ds_lightbox);
                }
				
				jQuery('.ds-lightbox_exitfullscreen', plugin.ds_lightbox).hide(); // <- [DS:A]

                if (plugin.items.length > 1 && opts.nav) {
                    jQuery('.ds-lightbox_nav', plugin.ds_lightbox).show();
                } else {
                    jQuery('.ds-lightbox_nav', plugin.ds_lightbox).hide();
                }

                plugin.bindEvents();

            },
			
			// Fullscreen mode options: [DS:A]
			toggleFullScreen: function (elem) {
				// check if it fuulscreen now
				if ((document.fullScreenElement !== undefined && document.fullScreenElement === null) || (document.msFullscreenElement !== undefined && document.msFullscreenElement === null) || (document.mozFullScreen !== undefined && !document.mozFullScreen) || (document.webkitIsFullScreen !== undefined && !document.webkitIsFullScreen)) {
					// Not fullscreen now
					
				} else {
					// Fullscreen now 
					
				} 
			},
			
			openFullScreen: function (elem) {
				if (elem.requestFullScreen) {
					elem.requestFullScreen();
				} else if (elem.mozRequestFullScreen) {
					elem.mozRequestFullScreen();
				} else if (elem.webkitRequestFullScreen) {
					elem.webkitRequestFullScreen(Element.ALLOW_KEYBOARD_INPUT);
				} else if (elem.msRequestFullscreen) {
					elem.msRequestFullscreen();
				}
				
				jQuery('.ds-lightbox_fullscreen', plugin.ds_lightbox).hide();
				jQuery('.ds-lightbox_exitfullscreen', plugin.ds_lightbox).show();
				jQuery(".ds-lightbox").addClass("ds-lightbox_blackbkg");
			},
			
			cancelFullScreen: function (elem) {
				if (document.cancelFullScreen) {
						document.cancelFullScreen();
				} else if (document.mozCancelFullScreen) {
					document.mozCancelFullScreen();
				} else if (document.webkitCancelFullScreen) {
					document.webkitCancelFullScreen();
				} else if (document.msExitFullscreen) {
					document.msExitFullscreen();
				}
				
				jQuery('.ds-lightbox_exitfullscreen', plugin.ds_lightbox).hide();
				jQuery('.ds-lightbox_fullscreen', plugin.ds_lightbox).show();
				jQuery(".ds-lightbox").removeClass("ds-lightbox_blackbkg");
			},
			// End of Fullscreen mode options: [DS:A]

            loadImage: function () {
                if(opts.blur) {
                    jQuery("body").addClass("blurred");
                }
                jQuery("img", plugin.ds_lightbox).remove();
                plugin.ds_lightbox.fadeIn(opts.fadeIn_speed).append('<span class="ds-lightbox_loading"></span>'); // <- [DS:C]

                var img = jQuery('<img src="' + jQuery(plugin.current).attr('src') + '" draggable="false">'); // 'href' to 'src' <- [DS:C]

                jQuery(img).load(function () {
                    jQuery('.ds-lightbox_loading').remove();
                    plugin.ds_lightbox.append(img);
                    plugin.image = jQuery("img", plugin.ds_lightbox).hide();
                    plugin.resizeImage();
                    plugin.setCaption();
					
					// loop navigation: [DS:A]
					if (!opts.navLoop && opts.nav) {
						if (plugin.getCurrentIndex() >= plugin.items.length - 1) {
							jQuery('.ds-lightbox_nav--next', plugin.ds_lightbox).hide();
						}else{
							jQuery('.ds-lightbox_nav--next', plugin.ds_lightbox).show();
						}
						if (plugin.getCurrentIndex() <= 0) {
							jQuery('.ds-lightbox_nav--prev', plugin.ds_lightbox).hide();
						}else{
							jQuery('.ds-lightbox_nav--prev', plugin.ds_lightbox).show();
						}
					}	
					// End of loop navigation [DS:A]
                });
            },

            setCaption: function () {
				
				// Image description logic: [DS:A]
				//var caption = $(plugin.current).data('caption');
				var ds_alt = jQuery(plugin.current).attr('alt');
				var ds_title = jQuery(plugin.current).attr('title');
				
				//if (caption == undefined || caption == ''){
					if 	(ds_title != undefined && ds_title != '') {
						var caption = ds_title;
					} else {
						if 	(ds_alt != undefined && ds_alt != '' && ds_title != '')	{
							var caption = ds_alt;
						}
					}
				//}
				// End of Image description logic [DS:A]
				
                if(!!caption && caption.length > 0) {
                    plugin.caption.fadeIn(); // <- [DS:A]
                    jQuery('p', plugin.caption).text(caption);
                }else{
                    plugin.caption.hide();
                }
            },

            resizeImage: function () {
                var ratio, wHeight, wWidth, iHeight, iWidth;
                wHeight = jQuery(window).height() - opts.margin;
                wWidth = jQuery(window).outerWidth(true) - opts.margin;
                plugin.image.width('').height('');
                iHeight = plugin.image.height();
                iWidth = plugin.image.width();
                if (iWidth > wWidth) {
                    ratio = wWidth / iWidth;
                    iWidth = wWidth;
                    iHeight = Math.round(iHeight * ratio);
                }
                if (iHeight > wHeight) {
                    ratio = wHeight / iHeight;
                    iHeight = wHeight;
                    iWidth = Math.round(iWidth * ratio);
                }

                plugin.image.width(iWidth).height(iHeight).css({
						'top': (jQuery(window).height() - plugin.image.outerHeight()) / 2 + 'px',
						'left': (jQuery(window).width() - plugin.image.outerWidth()) / 2 + 'px'
					}).show();
                plugin.locked = false;
            },

            getCurrentIndex: function () {
                return jQuery.inArray(plugin.current, plugin.items);
            },

            next: function () {
                if (plugin.locked) {
                    return false;
                }
                plugin.locked = true;
                if (plugin.getCurrentIndex() >= plugin.items.length - 1) {
                    jQuery(plugin.items[0]).click();
                } else {
                    jQuery(plugin.items[plugin.getCurrentIndex() + 1]).click();
                }
            },

            previous: function () {
                if (plugin.locked) {
                    return false;
                }
                plugin.locked = true;
                if (plugin.getCurrentIndex() <= 0) {
                    jQuery(plugin.items[plugin.items.length - 1]).click();
                } else {
                    jQuery(plugin.items[plugin.getCurrentIndex() - 1]).click();
                }
            },

            bindEvents: function () {
                jQuery(plugin.items).click(function (e) {
                    if(!plugin.ds_lightbox.is(":visible") && (jQuery(window).width() < opts.minSize || jQuery(window).height() < opts.minSize)) {
                        jQuery(this).attr("target", "_blank");
                        return;
                    }
                    var self = jQuery(this)[0];
                    e.preventDefault();
                    plugin.current = self;
                    plugin.loadImage();

                    // Bind Keyboard Shortcuts
                    jQuery(document).on('keydown', function (e) {
                        // CLOSE lightbox with ESC
                        if (e.keyCode === 27) {
                            plugin.close();
                        }
                        // Go to NEXT image pressing the right key
						if (e.keyCode === 39 && !(!opts.navLoop && plugin.getCurrentIndex() >= plugin.items.length - 1)  && opts.nav) { // <- [DS:C]
							plugin.next();
                        }
                        // Go to PREVIOUS image pressing the left key
                        if (e.keyCode === 37 && !(!opts.navLoop && (plugin.getCurrentIndex() <= 0))  && opts.nav) { // <- [DS:C]
                            plugin.previous();
                        }
                    });
                });

                // Add click state
                plugin.ds_lightbox.on('click', function (e) {
                    //if (this === e.target) { // <-  on overlay background only [DS:C]
						plugin.cancelFullScreen(document.body); // <- [DS:A]
                        plugin.close();
                    //} // <-  on overlay background only [DS:C]
                });

                // Previous click
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_nav--prev', function () {
                    plugin.previous();
                    return false;
                });

                // Next click
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_nav--next', function () {
                    plugin.next();
                    return false;
                });

                // Close click
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_close', function () {
					plugin.cancelFullScreen(document.body);//   <- [DS:A]
                    plugin.close();
                    return false;
                });
				
				// Fullscreen click [DS:A]
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_fullscreen', function () {
                    plugin.openFullScreen(document.body);
                    return false;
                });
				// End of Fullscreen click [DS:A]
				
				// Fullscreen Exit click [DS:A]
                jQuery(plugin.ds_lightbox).on('click', '.ds-lightbox_exitfullscreen', function () {
                    plugin.cancelFullScreen(document.body);
                    return false;
                });
				// End of Fullscreen Exit click [DS:A]

                jQuery(window).resize(function () {
                    if (!plugin.image) {
                        return;
                    }
                    plugin.resizeImage();
                });
            },

            close: function () {
                jQuery(document).off('keydown'); // Unbind all key events each time the lightbox is closed
                jQuery(plugin.ds_lightbox).fadeOut(opts.fadeOut_speed);
                jQuery('body').removeClass('blurred');
            }
        };

        jQuery.extend(opts, options);

        plugin.init(this);
    };

})(jQuery);